@@ -10,12 +10,14 @@ TODO:
 
 __all__ = ['CSSStyleSheet']
 
+import xml.dom
+
+import cssutils.stylesheets
 from cssutils.helper import Deprecated
 from cssutils.util import _Namespaces, _readUrl
+
 from .cssrule import CSSRule
 from .cssvariablesdeclaration import CSSVariablesDeclaration
-import cssutils.stylesheets
-import xml.dom
 
 
 class CSSStyleSheet(cssutils.stylesheets.StyleSheet):
@@ -78,12 +80,7 @@ class CSSStyleSheet(cssutils.stylesheets.StyleSheet):
             mediaText = self.media.mediaText
         else:
             mediaText = None
-        return "cssutils.css.{}(href={!r}, media={!r}, title={!r})".format(
-            self.__class__.__name__,
-            self.href,
-            mediaText,
-            self.title,
-        )
+        return f"cssutils.css.{self.__class__.__name__}(href={self.href!r}, media={mediaText!r}, title={self.title!r})"
 
     def __str__(self):
         if self.media:
@@ -529,11 +526,11 @@ class CSSStyleSheet(cssutils.stylesheets.StyleSheet):
 
         try:
             rule = self._cssRules[index]
-        except IndexError:
+        except IndexError as err:
             raise xml.dom.IndexSizeErr(
                 'CSSStyleSheet: %s is not a valid index in the rulelist of '
                 'length %i' % (index, self._cssRules.length)
-            )
+            ) from err
         else:
             if rule.type == rule.NAMESPACE_RULE:
                 # check all namespacerules if used
