@@ -6,7 +6,7 @@ css = '''
 @font-face {
   font-family: 'WebFont';
   src: url('myfont.eot');  /* IE6-8 */
-  src: local('xxx'), 
+  src: local('xxx'),
         url('myfont.woff') format('woff'),  /* FF3.6, IE9 */
         url('myfont.ttf') format('truetype');  /* Saf3+,Chrome,FF3.5,Opera10+ */
 }
@@ -26,9 +26,8 @@ font: normal 1px/5em Arial, sans-serif;
 p = cssutils.CSSParser(parseComments=False)
 sheet = p.parseString(10*css)
 """
-t = timeit.Timer(do)       # outside the try/except
+t = timeit.Timer(do)  # outside the try/except
 try:
-    print(t.timeit(20))    # or t.repeat(...)
-except:
+    print(t.timeit(20))  # or t.repeat(...)
+except Exception:
     print(t.print_exc())
-    
\ No newline at end of file
