@@ -1,14 +1,15 @@
-import cssutils
 import logging
 import os
 import sys
 import timeit
-import urllib.request
 import urllib.error
 import urllib.parse
+import urllib.request
 import xml
 import xml.dom
 
+import cssutils
+
 sys.stdout.write(sys.version)
 print()
 
@@ -129,7 +130,7 @@ if 1:
 font-family : a  b;
 }
 '''
-    cssutils.parseString(s).cssText
+    cssutils.parseString(s).cssText  # noqa: B018
     sys.exit(1)
 
     import cssutils
@@ -740,9 +741,7 @@ if 1:  # noqa: C901
                 if vi.cssValueType == vi.CSS_VARIABLE:
                     if vi.value:
                         print(
-                            '+ CSSValueList: Replacing {!r} with {!r}'.format(
-                                p.value, vi.value
-                            )
+                            f'+ CSSValueList: Replacing {p.value!r} with {vi.value!r}'
                         )
                         newvalue.append(vi.value)
                     else:
